@@ -133,14 +133,19 @@ def merge_dict(
     source: Dict[Any, Any], destination: Dict[Any, Any], merge_list_items: bool = True
 ) -> Dict[Any, Any]:
     """Merge two nested dict/list structures."""
+    if not source:
+        return destination
     for key, value in source.items():
         if isinstance(value, dict):
             # get node or create one
             node = destination.setdefault(key, {})
-            merge_dict(value, node, merge_list_items)
+            if node is None:
+                destination[key] = value
+            else:
+                merge_dict(value, node, merge_list_items)
         elif isinstance(value, list):
             if key not in destination:
-                destination[key] = value
+                destination[key] = []
             if isinstance(destination[key], list):
                 for i in value:
                     merge_list_item(i, destination[key], merge_list_items)
